/*******************************************************************************
* File Name: SwitchISR_intc.c  
* Version 1.10
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <SwitchISR.H>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START SwitchISR_intc` */
#include <device.h>
/* `#END` */


/*******************************************************************************
* Function Name: SwitchISR_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void SwitchISR_Start(void)
{
    /* For all we know the interrupt is active. */
    SwitchISR_Disable();

    /* Set the ISR to point to the SwitchISR Interrupt. */
    SwitchISR_SetVector(SwitchISR_Interrupt);

    /* Set the priority. */
    SwitchISR_SetPriority(SwitchISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    SwitchISR_Enable();
}

/*******************************************************************************
* Function Name: SwitchISR_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void SwitchISR_Stop(void)
{
    /* Disable this interrupt. */
    SwitchISR_Disable();

    /* Set the ISR to point to the passive one. */
//    SwitchISR_SetVector(CyDefaultInterrupt);
}

/*******************************************************************************
* Function Name: SwitchISR_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for SwitchISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(SwitchISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START SwitchISR_Interrupt` */
	static uint8 val = 0;
	
	SwitchPin_Write(val);
	if (val == 0)
	{
		val = 1;
		PhaseAccum_1_WriteIncrement(65536 / 25);
	}
	else
	{
		val = 0;
		PhaseAccum_1_WriteIncrement(65536 / 50);
	}

    /* `#END` */
}


/*******************************************************************************
* Function Name: SwitchISR_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SwitchISR_SetVector(cyisraddress address)
{
    CY_SET_REG16(SwitchISR_INTC_VECTOR, (uint16) address);
}

/*******************************************************************************
* Function Name: SwitchISR_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress SwitchISR_GetVector(void)
{
    return (cyisraddress) CY_GET_REG16(SwitchISR_INTC_VECTOR);
}

/*******************************************************************************
* Function Name: SwitchISR_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SwitchISR_SetPriority(uint8 priority)
{
    *SwitchISR_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: SwitchISR_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 SwitchISR_GetPriority(void)
{
    uint8 priority;


    priority = *SwitchISR_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: SwitchISR_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SwitchISR_Enable(void)
{
    /* Enable the general interrupt. */
    *SwitchISR_INTC_SET_EN = SwitchISR__INTC_MASK;
}

/*******************************************************************************
* Function Name: SwitchISR_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 SwitchISR_GetState(void)
{
    /* Get the state of the general interrupt. */
    return (*SwitchISR_INTC_SET_EN & SwitchISR__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: SwitchISR_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SwitchISR_Disable(void)
{
    /* Disable the general interrupt. */
    *SwitchISR_INTC_CLR_EN = SwitchISR__INTC_MASK;
}

/*******************************************************************************
* Function Name: SwitchISR_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SwitchISR_SetPending(void)
{
    *SwitchISR_INTC_SET_PD = SwitchISR__INTC_MASK;
}

/*******************************************************************************
* Function Name: SwitchISR_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SwitchISR_ClearPending(void)
{
    *SwitchISR_INTC_CLR_PD = SwitchISR__INTC_MASK;
}


















































