/*******************************************************************************
* File Name: SwitchISR_intc.h
* Version 1.10
*
*  Description:
*   Provides the function definitions for the Interrupt Controller.
*
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
#if !defined(__SwitchISR_INTC_H__)
#define __SwitchISR_INTC_H__


#include <cytypes.h>
#include <cyfitter.h>


/* Interrupt Controller API. */
void SwitchISR_Start(void);
void SwitchISR_Stop(void);

CY_ISR_PROTO(SwitchISR_Interrupt);

void SwitchISR_SetVector(cyisraddress address);
cyisraddress SwitchISR_GetVector(void);

void SwitchISR_SetPriority(uint8 priority);
uint8 SwitchISR_GetPriority(void);

void SwitchISR_Enable(void);
uint8 SwitchISR_GetState(void);
void SwitchISR_Disable(void);

void SwitchISR_SetPending(void);
void SwitchISR_ClearPending(void);


/* Interrupt Controller Constants */

/* Address of the INTC.VECT[x] register that contains the Address of the SwitchISR ISR. */
#define SwitchISR_INTC_VECTOR            ((reg16 *) SwitchISR__INTC_VECT)

/* Address of the SwitchISR ISR priority. */
#define SwitchISR_INTC_PRIOR             ((reg8 *) SwitchISR__INTC_PRIOR_REG)

/* Priority of the SwitchISR interrupt. */
#define SwitchISR_INTC_PRIOR_NUMBER      SwitchISR__INTC_PRIOR_NUM

/* Address of the INTC.SET_EN[x] byte to bit enable SwitchISR interrupt. */
#define SwitchISR_INTC_SET_EN            ((reg8 *) SwitchISR__INTC_SET_EN_REG)

/* Address of the INTC.CLR_EN[x] register to bit clear the SwitchISR interrupt. */
#define SwitchISR_INTC_CLR_EN            ((reg8 *) SwitchISR__INTC_CLR_EN_REG)

/* Address of the INTC.SET_PD[x] register to set the SwitchISR interrupt state to pending. */
#define SwitchISR_INTC_SET_PD            ((reg8 *) SwitchISR__INTC_SET_PD_REG)

/* Address of the INTC.CLR_PD[x] register to clear the SwitchISR interrupt. */
#define SwitchISR_INTC_CLR_PD            ((reg8 *) SwitchISR__INTC_CLR_PD_REG)

/* __SwitchISR_INTC_H__ */
#endif

