
//`#start header` -- edit after this line, do not edit this line
// ========================================
//
// Copyright Cypress Semiconductor
// All Rights Reserved
// UNPUBLISHED, LICENSED SOFTWARE.
//
// CONFIDENTIAL AND PROPRIETARY INFORMATION
// WHICH IS THE PROPERTY OF Cypress Semiconductor.
//
// ========================================
`include "cypress.v"
//`#end` -- edit above this line, do not edit this line
// Generated on 11/16/2009 at 10:15
// Component: PhaseAccum
module PhaseAccum (
	clock
);
	input   clock;

//`#start body` -- edit after this line, do not edit this line

	// Register Usage:
	//    D0 - Base Address of the Array of points in SRAM
	//    D1 - Programmable increment
	//    A0 - Phase Accumulator
	//    A1 - Address Calculation Accumulator
	//    F0 - FIFO of address values out
	//    F1 - Not Used

	// State machine values
	// State machine is a simple counter
	localparam PHASEACCUM_STATE_IDLE	 	= 3'd0;
	localparam PHASEACCUM_STATE_INCREMENT 	= 3'd1;
	localparam PHASEACCUM_STATE_TRANSFER 	= 3'd2;
	localparam PHASEACCUM_STATE_SHIFT		= 3'd3;
	localparam PHASEACCUM_STATE_ADD			= 3'd4;
	localparam PHASEACCUM_STATE_SEND		= 3'd5;
	
	// State machine state value also drives address to datapath
	reg [2:0] state;
	// Counter of the number of shifts required
	reg [2:0] count;
	
	// One bit control register for enabling
	wire [7:0] control;
	wire enable = control[0];

	// FIFO full status
	// Using the MSB of f0_blk_stat, so make sure the DMA reads from the LSB FIFO first
	wire [1:0] f0_blk_stat;
	wire blk_stat = f0_blk_stat[1];
	// Load the FIFO if in the send state and the FIFO is not full
	wire f0_load = (state == PHASEACCUM_STATE_SEND) && (!blk_stat);

	always @(posedge clock) begin
		if (enable)
		begin
			case (state)
				PHASEACCUM_STATE_IDLE:
					state <= PHASEACCUM_STATE_INCREMENT;
				PHASEACCUM_STATE_INCREMENT:
					state <= PHASEACCUM_STATE_TRANSFER;
				PHASEACCUM_STATE_TRANSFER:
				begin
					state <= PHASEACCUM_STATE_SHIFT;
					count <= 0;
				end
				PHASEACCUM_STATE_SHIFT:
				begin
					// Need 5 shifts in addition to the shift that is done
					// as part of the TRANSFER state
					if (count == 3'd4)	
					begin
						state <= PHASEACCUM_STATE_ADD;
					end
					else
					begin
						count <= count + 1;
					end
				end
				PHASEACCUM_STATE_ADD:
					state <= PHASEACCUM_STATE_SEND;
				PHASEACCUM_STATE_SEND:
				begin
					if (!blk_stat)	// not full
					begin
						state <= PHASEACCUM_STATE_INCREMENT;
					end
				end
			endcase
		end
		else
		begin
			state <= PHASEACCUM_STATE_IDLE;
		end
	end
	
	// Control Register
	cy_psoc3_control #(.cy_init_value (8'b00000000), .cy_force_order(1)) 
	ControlReg (
		/* output [07:00] */ .control(control)
	);
	
	// 16-Bit Datapath
	cy_psoc3_dp16 #(.cy_dpconfig_a(
	{
		`CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
		`CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG0 Comment:IDLE */
		`CS_ALU_OP__ADD, `CS_SRCA_A0, `CS_SRCB_D1,
		`CS_SHFT_OP_PASS, `CS_A0_SRC__ALU, `CS_A1_SRC_NONE,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG1 Comment:INCREMENT */
		`CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
		`CS_SHFT_OP___SR, `CS_A0_SRC_NONE, `CS_A1_SRC__ALU,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG2 Comment:TRANSFER */
		`CS_ALU_OP_PASS, `CS_SRCA_A1, `CS_SRCB_D0,
		`CS_SHFT_OP___SR, `CS_A0_SRC_NONE, `CS_A1_SRC__ALU,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG3 Comment:SHIFT */
		`CS_ALU_OP__ADD, `CS_SRCA_A1, `CS_SRCB_D0,
		`CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC__ALU,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG4 Comment:ADD */
		`CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
		`CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG5 Comment:SEND */
		`CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
		`CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG6 Comment: */
		`CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
		`CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG7 Comment: */
		  8'hFF, 8'h00,	/*SC_REG4	Comment: */
		  8'hFF, 8'hFF,	/*SC_REG5	Comment: */
		`SC_CMPB_A1_D1, `SC_CMPA_A1_D1, `SC_CI_B_ARITH,
		`SC_CI_A_ARITH, `SC_C1_MASK_DSBL, `SC_C0_MASK_DSBL,
		`SC_A_MASK_DSBL, `SC_DEF_SI_0, `SC_SI_B_DEFSI,
		`SC_SI_A_CHAIN, /*SC_REG6 Comment: */
		`SC_A0_SRC_ACC, `SC_SHIFT_SR, 1'b0,
		1'b0, `SC_FIFO1_BUS, `SC_FIFO0__A1,
		`SC_MSB_DSBL, `SC_MSB_BIT0, `SC_MSB_NOCHN,
		`SC_FB_NOCHN, `SC_CMP1_NOCHN,
		`SC_CMP0_NOCHN, /*SC_REG7 Comment: */
		 10'h0, `SC_FIFO_CLK__DP,`SC_FIFO_CAP_AX,
		`SC_FIFO_LEVEL,`SC_FIFO__SYNC,`SC_EXTCRC_DSBL,
		`SC_WRK16CAT_DSBL /*SC_REG8 Comment: */
}), .cy_dpconfig_b(
	{
		`CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
		`CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG0 Comment:IDLE */
		`CS_ALU_OP__ADD, `CS_SRCA_A0, `CS_SRCB_D1,
		`CS_SHFT_OP_PASS, `CS_A0_SRC__ALU, `CS_A1_SRC_NONE,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG1 Comment:INCREMENT */
		`CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
		`CS_SHFT_OP___SR, `CS_A0_SRC_NONE, `CS_A1_SRC__ALU,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG2 Comment:TRANSFER */
		`CS_ALU_OP_PASS, `CS_SRCA_A1, `CS_SRCB_D0,
		`CS_SHFT_OP___SR, `CS_A0_SRC_NONE, `CS_A1_SRC__ALU,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG3 Comment:SHIFT */
		`CS_ALU_OP__ADD, `CS_SRCA_A1, `CS_SRCB_D0,
		`CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC__ALU,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG4 Comment:ADD */
		`CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
		`CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG5 Comment:SEND */
		`CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
		`CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG6 Comment: */
		`CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
		`CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
		`CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
		`CS_CMP_SEL_CFGA, /*CS_REG7 Comment: */
		  8'hFF, 8'h00,	/*SC_REG4	Comment: */
		  8'hFF, 8'hFF,	/*SC_REG5	Comment: */
		`SC_CMPB_A1_D1, `SC_CMPA_A1_D1, `SC_CI_B_ARITH,
		`SC_CI_A_CHAIN, `SC_C1_MASK_DSBL, `SC_C0_MASK_DSBL,
		`SC_A_MASK_DSBL, `SC_DEF_SI_0, `SC_SI_B_DEFSI,
		`SC_SI_A_DEFSI, /*SC_REG6 Comment: */
		`SC_A0_SRC_ACC, `SC_SHIFT_SR, 1'b0,
		1'b0, `SC_FIFO1_BUS, `SC_FIFO0__A1,
		`SC_MSB_DSBL, `SC_MSB_BIT0, `SC_MSB_NOCHN,
		`SC_FB_NOCHN, `SC_CMP1_NOCHN,
		`SC_CMP0_NOCHN, /*SC_REG7 Comment: */
		 10'h0, `SC_FIFO_CLK__DP,`SC_FIFO_CAP_AX,
		`SC_FIFO_LEVEL,`SC_FIFO__SYNC,`SC_EXTCRC_DSBL,
		`SC_WRK16CAT_DSBL /*SC_REG8 Comment: */
	})) Datapath(
		/*  input                   */  .clk(clock),
		/*  input   [02:00]         */  .cs_addr(state),
		/*  input                   */  .route_si(1'b0),
		/*  input                   */  .route_ci(1'b0),
		/*  input                   */  .f0_load(f0_load),
		/*  input                   */  .f1_load(1'b0),
		/*  input                   */  .d0_load(1'b0),
		/*  input                   */  .d1_load(1'b0),
		/*  output  [01:00]         */  .ce0(),
		/*  output  [01:00]         */  .cl0(),
		/*  output  [01:00]         */  .z0(),
		/*  output  [01:00]         */  .ff0(),
		/*  output  [01:00]         */  .ce1(),
		/*  output  [01:00]         */  .cl1(),
		/*  output  [01:00]         */  .z1(),
		/*  output  [01:00]         */  .ff1(),
		/*  output  [01:00]         */  .ov_msb(),
		/*  output  [01:00]         */  .co_msb(),
		/*  output  [01:00]         */  .cmsb(),
		/*  output  [01:00]         */  .so(),
		/*  output  [01:00]         */  .f0_bus_stat(),
		/*  output  [01:00]         */  .f0_blk_stat(f0_blk_stat),
		/*  output  [01:00]         */  .f1_bus_stat(),
		/*  output  [01:00]         */  .f1_blk_stat()
	);

//`#end` -- edit above this line, do not edit this line
endmodule
//`#start footer` -- edit after this line, do not edit this line
//`#end` -- edit above this line, do not edit this line
